@@ -7,13 +7,11 @@ import logging
 
 
 logging.basicConfig(level=logging.ERROR)
-import shutil
 import zmq
 import zmq.asyncio
 from npc_engine.services.utils.config import (
-    get_model_type_name,
+    get_type_from_dict,
     validate_hub_model,
-    validate_local_model,
 )
 from npc_engine.server.metadata_manager import MetadataManager
 
@@ -30,18 +28,38 @@ from multiprocessing import freeze_support
 @click.option("--verbose/--silent", "-v", default=False, help="Enable verbose output.")
 def cli(verbose: bool):
     """NPC engine JSON RPC server CLI."""
-    # Use the verbosity count to determine the logging level...
     logger.remove()
     if verbose:
         logger.add(
-            sys.stdout, format="{time} {level} {message}", level="INFO", enqueue=True
+            sys.stdout, format="{time} {level} {message}", level="DEBUG", enqueue=True
+        )
+        logger.add(
+            os.path.join("Logs", "npc-engine.log"),
+            format="{time} {level} {message}",
+            level="DEBUG",
+            enqueue=True,
+            rotation="500 MB",
         )
         click.echo(
-            click.style("Verbose logging is enabled. (LEVEL=INFO)", fg="yellow",)
+            click.style(
+                "Verbose logging is enabled. (LEVEL=INFO)",
+                fg="yellow",
+            )
+        )
+    else:
+        logger.add(
+            sys.stdout, format="{time} {level} {message}", level="WARNING", enqueue=True
+        )
+        logger.add(
+            os.path.join("Logs", "npc-engine.log"),
+            format="{time} {level} {message}",
+            level="WARNING",
+            enqueue=True,
+            rotation="500 MB",
         )
 
 
-@cli.command()
+@cli.command("run")
 @click.option("--port", default="5555", help="The port to listen on.")
 @click.option(
     "--start-all/--dont-start",
@@ -54,6 +72,11 @@ def cli(verbose: bool):
     help="The path to the folder with service configs",
 )
 @click.option("--http/--zmq", default=False, help="Whether to use HTTP or ZMQ.")
+def run_command(port: str, start_all: bool, models_path: str, http: bool):
+    """Start the server."""
+    run(port, start_all, models_path, http)
+
+
 def run(port: str, start_all: bool, models_path: str, http: bool):
     """Load the models and start JSONRPC server."""
     from npc_engine.server.control_service import ControlService
@@ -80,7 +103,7 @@ def run(port: str, start_all: bool, models_path: str, http: bool):
     default=os.environ.get("NPC_ENGINE_MODELS_PATH", "./models"),
     help="The path to the folder with service configs.",
 )
-def download_default_models(models_path: str):
+def download_default_models(models_path: str):  # pragma: no cover
     """Download default models into the folder."""
     model_names = [
         "npc-engine/exported-paraphrase-MiniLM-L6-v2",
@@ -88,10 +111,19 @@ def download_default_models(models_path: str):
         "npc-engine/exported-nemo-quartznet-ctc-stt",
         "npc-engine/exported-flowtron-waveglow-librispeech-tts",
     ]
-    for model in model_names:
+    revs = [
+        "main",
+        "crop-fix",
+        "main",
+        "main",
+    ]
+    for model, rev in zip(model_names, revs):
         logger.info("Downloading model {}", model)
         logger.info("Downloading {}", model)
-        snapshot_download(repo_id=model, revision="main", cache_dir=models_path)
+        tmp_folder = snapshot_download(
+            repo_id=model, revision=rev, cache_dir=models_path
+        )
+        os.rename(tmp_folder, os.path.join(models_path, model.split("/")[-1]))
 
 
 @cli.command()
@@ -145,7 +177,7 @@ def describe(models_path: str, model_id: str):
     metadata = model_manager.get_metadata(model_id)
 
     click.echo(metadata["id"])
-    click.echo(metadata["type"])
+    click.echo(get_type_from_dict(metadata))
     click.echo("Service description:")
     click.echo(metadata["service_description"])
     click.echo("Model description:")
@@ -155,86 +187,30 @@ def describe(models_path: str, model_id: str):
 @cli.command()
 @click.option(
     "--models-path",
-    default=os.environ.get("NPC_ENGINE_MODELS_PATH", "./models",),
+    default=os.environ.get(
+        "NPC_ENGINE_MODELS_PATH",
+        "./models",
+    ),
     help="The path to the folder with service configs.",
 )
+@click.option("--revision", default="main", help="The commit/branch to use.")
 @click.argument("model_id")
-def download_model(models_path: str, model_id: str):
+def download_model(models_path: str, revision, model_id: str):  # pragma: no cover
     """Download a model from Huggingface Hub."""
-    model_correct = validate_hub_model(model_id)
+    model_correct = validate_hub_model(models_path, model_id)
     if model_correct:
         logger.info("Downloading model {}", model_id)
-        snapshot_download(repo_id=model_id, revision="main", cache_dir=models_path)
+        tmp_folder = snapshot_download(
+            repo_id=model_id, revision=revision, cache_dir=models_path
+        )
+        os.rename(tmp_folder, os.path.join(models_path, model_id.split("/")[-1]))
     else:
-        if click.confirm(
+        click.echo(
             click.style(
-                f"{model_id} is not a valid npc-engine model."
-                + " \nDo you want to export it?",
+                f"{model_id} is not a valid npc-engine model. You first need to import it.",
                 fg="yellow",
             )
-        ):
-            export_model(models_path, model_id, True)
-
-
-@cli.command()
-@click.option(
-    "--models-path",
-    default=os.environ.get("NPC_ENGINE_MODELS_PATH", "./models",),
-    help="The path to the folder with service configs.",
-)
-@click.argument("model_id")
-def export_model(models_path: str, model_id: str, remove_source: bool = False):
-    """Export the model."""
-    from npc_engine.exporters.base_exporter import Exporter
-
-    logger.info("Downloading source model {}", model_id)
-    if os.path.exists(model_id):
-        source_path = model_id
-    else:
-        source_path = snapshot_download(
-            repo_id=model_id, revision="main", cache_dir=models_path
         )
-        remove_source = True
-    export_path = os.path.join(
-        models_path, "exported-" + model_id.replace("\\", "/").split("/")[-1],
-    )
-    os.makedirs(export_path, exist_ok=True)
-
-    logger.info("Exporting model {} to {}", model_id, export_path)
-    exporters = Exporter.get_exporters()
-    click.echo("Available exporters:")
-    for i, exporter in enumerate(exporters):
-        click.echo(f"{i+1}. {exporter.description()}")
-    exporter_id = click.prompt("Please select an exporter", type=int)
-    exporter = exporters[exporter_id - 1]
-    exporter.export(source_path, export_path)
-    exporter.create_config(export_path)
-    if remove_source:
-        shutil.rmtree(source_path)
-
-
-@cli.command()
-@click.option(
-    "--models-path",
-    default=os.environ.get("NPC_ENGINE_MODELS_PATH", "./models"),
-    help="The path to the folder with service configs.",
-)
-@click.argument("model_id")
-def test_model(models_path: str, model_id: str):
-    """Send test request to the model and print reply."""
-    from npc_engine.exporters.base_exporter import Exporter
-
-    if not validate_local_model(models_path, model_id):
-        click.echo(
-            click.style(f"{(model_id)} is not a valid npc-engine model.", fg="red",)
-        )
-        return 1
-    model_type = get_model_type_name(models_path, model_id)
-    exporters = Exporter.get_exporters()
-    for exporter in exporters:
-        if exporter.get_model_name() == model_type:
-            exporter.test_model(models_path, model_id)
-            return 0
 
 
 @cli.command()
