@@ -43,6 +43,4 @@ def start_test_server(port: str, models_path: str):  # pragma: no cover
 
 def build_ipc_uri(service_id: str) -> str:
     """Build ipc uri for the given service."""
-    return (
-        f"ipc://{os.path.join(user_cache_dir('npc-engine', 'NpcEngine'), service_id)}"
-    )
+    return f"ipc://{os.path.join(user_cache_dir('npc-engine'), service_id)}"
